@@ -13,6 +13,7 @@ from .pembuangan_sampah import PembuanganSampah
 from .penerangan import Penerangan
 from .status_lahan import StatusLahan
 from .sumber_air_mandi import SumberAirMandi
+from .sumber_air_minum import SumberAirMinum
 from .sumber_kayu_bakar import SumberKayuBakar
 from .tempat_tinggal import TempatTinggal
 from .ya_tidak import YaTidak
@@ -30,6 +31,7 @@ cattr.register_structure_hook(PembuanganSampah, PembuanganSampah.from_str)  # ty
 cattr.register_structure_hook(Penerangan, Penerangan.from_str)  # type: ignore
 cattr.register_structure_hook(StatusLahan, StatusLahan.from_str)  # type: ignore
 cattr.register_structure_hook(SumberAirMandi, SumberAirMandi.from_str)  # type: ignore
+cattr.register_structure_hook(SumberAirMinum, SumberAirMinum.from_str)  # type: ignore
 cattr.register_structure_hook(SumberKayuBakar, SumberKayuBakar.from_str)  # type: ignore
 cattr.register_structure_hook(TempatTinggal, TempatTinggal.from_str)  # type: ignore
 cattr.register_structure_hook(YaTidak, YaTidak.from_str)  # type: ignore
@@ -48,6 +50,7 @@ __all__ = [
     "Penerangan",
     "StatusLahan",
     "SumberAirMandi",
+    "SumberAirMinum",
     "SumberKayuBakar",
     "TempatTinggal",
     "YaTidak",
